@@ -2,4 +2,4 @@
 
 myattr = 123
 
-import does_not_exist
+import does_not_exist  # noqa
