@@ -15,10 +15,7 @@ class Response:
             {
                 "type": prefix + "http.response.start",
                 "status": self.status_code,
-                "headers": [
-                    [key.encode(), value.encode()]
-                    for key, value in self.headers.items()
-                ],
+                "headers": [[key.encode(), value.encode()] for key, value in self.headers.items()],
             }
         )
         await send({"type": prefix + "http.response.body", "body": self.body})
