@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 import logging
+from collections.abc import Iterator
 from pathlib import Path
 from socket import socket
-from typing import Callable, Iterator
+from typing import Callable
 
 from uvicorn.config import Config
 from uvicorn.supervisors.basereload import BaseReload
@@ -23,7 +24,7 @@ class StatReload(BaseReload):
         self.mtimes: dict[Path, float] = {}
 
         if config.reload_excludes or config.reload_includes:
-            logger.warning("--reload-include and --reload-exclude have no effect unless " "watchfiles is installed.")
+            logger.warning("--reload-include and --reload-exclude have no effect unless watchfiles is installed.")
 
     def should_restart(self) -> list[Path] | None:
         self.pause()
